@@ -82,7 +82,7 @@ on_stream_read(uv_stream_t* handle, int nread, uv_buf_t buf)
     Py_INCREF(self);
 
     if (nread >= 0) {
-        data = PyString_FromStringAndSize(buf.base, nread);
+        data = PyBytes_FromStringAndSize(buf.base, nread);
         py_errorno = Py_None;
         Py_INCREF(Py_None);
     } else if (nread < 0) {
@@ -463,8 +463,8 @@ Stream_func_writelines(Stream *self, PyObject *args)
                 Py_DECREF(iter);
                 goto error;
             }
-            data_str = PyString_AS_STRING(encoded);
-            data_len = PyString_GET_SIZE(encoded);
+            data_str = PyBytes_AS_STRING(encoded);
+            data_len = PyBytes_GET_SIZE(encoded);
             tmp = (char *) PyMem_Malloc(data_len);
             if (!tmp) {
                 Py_DECREF(item);
