@@ -1,6 +1,8 @@
 
-from common import unittest2
+import gc
 import pyuv
+import weakref
+from common import unittest2
 
 
 class WalkTest(unittest2.TestCase):
@@ -15,6 +17,8 @@ class WalkTest(unittest2.TestCase):
             timer.close()
         loop = pyuv.Loop.default_loop()
         timer = pyuv.Timer(loop)
+        w_timer = weakref.ref(timer)
+        self.assertNotEqual(w_timer(), None)
         timer.start(timer_cb, 0.1, 0.0)
         loop.run()
         handles = []
@@ -22,6 +26,11 @@ class WalkTest(unittest2.TestCase):
             handles.append(handle)
         loop.walk(walk_cb)
         self.assertTrue(timer not in handles)
+        handles = None
+        timer = None
+        gc.collect()
+        self.assertEqual(w_timer(), None)
+
 
 
 if __name__ == '__main__':
